==> ropa-1.1.4.tar.gz: ropa-1.1.4/ropa/services/export_service.py <==
# ropa
# Copyright (C) 2017-2018 orppra

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import subprocess
import sys

from PyQt4 import QtCore as qc

from ropa.services import DialogService


class ExportService:
    def __init__(self, app, lwc):
        self.app = app
        self.search_service = app.get_search_service()
        self.lwc = lwc
        self.dialog_service = DialogService()

    def open_exported(self, filepath):
        if sys.platform.startswith('linux'):
            subprocess.call(["xdg-open", filepath])

        # Let's ignore this for now,
        # I don't even know how to set python qt up on windows
        #
        # elif sys.platform.startswith('win'):
        #     subprocess.call([filepath])

        elif sys.platform.startswith('darwin'):  # mac
            subprocess.call(["open", filepath])

    def pre_export(self):
        filepath = self.dialog_service.file_dialog('Export')
        gadgets = []
        for index in range(self.lwc.count()):
            block = self.lwc.get_item(index).data(qc.Qt.UserRole).toPyObject()
            for gadget in block.get_gadgets():
                gadgets.append(gadget)

        return filepath, gadgets

    def export_python_struct(self):
        filepath, gadgets = self.pre_export()

        with open(filepath, 'w') as outfile:
            outfile.write('p = ""\n')
            for gadget in gadgets:
                if self.search_service.get_addr_len() == 4:
                    outfile.write('p += struct.pack("<I", {})'
                                  .format(hex(gadget.get_addr())[:-1]))
                else:
                    outfile.write('p += struct.pack("<Q", {})'
                                  .format(hex(gadget.get_addr())[:-1]))

                outfile.write('  # ')
                for instruction in gadget.get_instructions():
                    outfile.write('{}; '.format(instruction.get_text()))

                outfile.write('\n')
            outfile.close()

        self.open_exported(filepath)

    def export_python_pwntools(self):
        filepath, gadgets = self.pre_export()

        with open(filepath, 'w') as outfile:
            outfile.write('p = ""\n')
            for gadget in gadgets:
                if self.search_service.get_addr_len() == 4:
                    outfile.write('p += p32({})'
                                  .format(hex(gadget.get_addr())[:-1]))
                else:
                    outfile.write('p += p64({})'
                                  .format(hex(gadget.get_addr())[:-1]))

                outfile.write('  # ')
                for instruction in gadget.get_instructions():
                    outfile.write('{}; '.format(instruction.get_text()))

                outfile.write('\n')
            outfile.close()

        self.open_exported(filepath)

==> ropa-1.1.5.tar.gz: ropa-1.1.5/ropa/services/export_service.py <==
# ropa
# Copyright (C) 2017-2018 orppra

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import subprocess
import sys

from ropa.services import DialogService


class ExportService:
    def __init__(self, app):
        self.app = app
        self.search_service = app.get_search_service()
        self.dialog_service = DialogService()

    def open_exported(self, filepath):
        if sys.platform.startswith('linux'):
            subprocess.call(["xdg-open", filepath])

        # Let's ignore this for now,
        # I don't even know how to set python qt up on windows
        #
        # elif sys.platform.startswith('win'):
        #     subprocess.call([filepath])

        elif sys.platform.startswith('darwin'):  # mac
            subprocess.call(["open", filepath])

    def export_block(self, block):
        res = ''
        if len(block.get_comments()) > 0:
            res += '\n'
            for line in block.get_comments().split('\n'):
                res += '# {}\n'.format(line)

        for gadget in block.get_gadgets():
            addr = hex(gadget.get_addr())[:-1]
            if self.search_service.get_addr_len() == 4:
                res += 'p += p32({})'.format(addr)
            else:
                res += 'p += p64({})'.format(addr)

            res += '  # '
            for instruction in gadget.get_instructions():
                res += '{}; '.format(instruction.get_text())

            res += '\n'

        if len(block.get_comments()) > 0:
            res += '\n'

        return res

    def export(self):
        filepath = self.dialog_service.file_dialog('Export')
        lwc = self.app.chain_list

        with open(filepath, 'w') as outfile:
            outfile.write('p = ""\n')

            for block in lwc.get_blocks():
                outfile.write(self.export_block(block))

            outfile.close()

        self.open_exported(filepath)
